@@ -4,7 +4,8 @@ use 5.008;
 use base qw(Module::Install::Base);
 use strict;
 
-our $VERSION = '0.102';
+our $VERSION = '0.103';
+our $AUTHOR_ONLY = 1;
 
 sub write_doap_changes {
 	my $self = shift;
@@ -28,17 +29,17 @@ Module::Install::DOAPChangeSets - write your distribution change log in RDF
 This package allows you to write your Changes file in Turtle or RDF/XML and
 autogenerate a human-readable text file.
 
-To do this, create an RDF file called "Changes.ttl" (or something like that)
+To do this, create an RDF file called "meta/changes.ttl" (or something like that)
 and describe your distribution's changes in RDF using the Dublin Core, DOAP,
 and DOAP Change Sets vocabularies. Then in your Makefile.PL, include:
 
-  write_doap_changes "Changes.ttl", "Changes", "turtle";
+  write_doap_changes "meta/changes.ttl", "Changes", "turtle";
 
 This line will read your data from the file named as the first argument,
 parse it using either Turtle or RDFXML parsers (the third argument), and
 output a human-readable changelog to the file named as the second argument.
 
-The defaults are "Changes.ttl", "Changes", "turtle", so if you name the
+The defaults are "meta/changes.ttl", "Changes", "turtle", so if you name the
 files like that, then you can exclude all the arguments and just include
 this in your Makefile.PL:
 
@@ -46,7 +47,7 @@ this in your Makefile.PL:
 
 There's also a line you can use to output a Changes.xml file:
 
-  write_doap_changes_xml "Changes.ttl", "Changes.xml", "turtle";
+  write_doap_changes_xml "meta/changes.ttl", "Changes.xml", "turtle";
 
 =head1 WHY?
 
@@ -68,7 +69,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010 by Toby Inkster
+Copyright (C) 2010-2011 by Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
